summaryrefslogtreecommitdiff
path: root/src/main_sound_configuration.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2025-03-20 22:00:15 +0100
committerCarl Hetherington <cth@carlh.net>2025-03-23 00:36:57 +0100
commit8efd6f75450037e685d78cc29dcebd82fe922741 (patch)
tree7a85267a4ca6a8668b3b23fee8f3ebf7dbb76128 /src/main_sound_configuration.h
parent4481f844c5dc5d84ec63f354f44c54022e101388 (diff)
Rename MainSoundConfiguration::to_string() -> as_string().
Trying to be consistent with the rule that to_string is a method which converts a parameter to a string (implying processing) whereas as_string is a class member which returns a string representation of the thing.
Diffstat (limited to 'src/main_sound_configuration.h')
-rw-r--r--src/main_sound_configuration.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/main_sound_configuration.h b/src/main_sound_configuration.h
index 1f9c18e9..b1fb9b77 100644
--- a/src/main_sound_configuration.h
+++ b/src/main_sound_configuration.h
@@ -65,7 +65,7 @@ class MainSoundConfiguration
public:
/** Set up a MainSoundConfiguration from a string. If the string is valid, valid() will
* subsequently return true and all accessors can be called. Otherwise, all accessors
* except to_string() will throw a MainSoundConfigurationError and to_string() will
* return the original invalid string.
*/
explicit MainSoundConfiguration(std::string);
@@ -84,7 +84,7 @@ public:
boost::optional<Channel> mapping (int index) const;
void set_mapping (int index, Channel channel);
- std::string to_string() const {
+ std::string as_string() const {
return _configuration;
}
@@ -65,7 +65,7 @@ class MainSoundConfiguration
/** Set up a MainSoundConfiguration from a string. If the string is valid, valid() will
* subsequently return true and all accessors can be called. Otherwise, all accessors
- * except to_string() will throw a MainSoundConfigurationError and to_string() will
+ * except as_string() will throw a MainSoundConfigurationError and as_string() will
* return the original invalid string.
*/